{{ title }}
Author: Wouter van Wijk
Description: MusicBox

- Home
- Now Playing
- Queue
- Playlists
- Browse
- Streams
- Search
- Alarm Clock
- Fullscreen
- Settings
- System
- Volume
- {% if hostname == serverIP %} {{programName}} running on {{ hostname }}:{{ serverPort}} {% else %} {{programName}} running on {{ hostname }} at {{ serverIP }}:{{ serverPort}} {% end %}

Close

###

####

Close

####

- Play
- Play All
- Play Track Next
- Add Track to Bottom of Queue
- Add All to Bottom of Queue
- Show Album
- Show Artist

## Artists

- Show Track Info...

- Play
- Add a Track Below
- Remove from Queue
- Show Album
- Show Artist

## Artists

- Show Track Info...

Add a Track to the Queue

Save Current Queue to a Playlist

A playlist with the same name already exists. Overwrite?

Are you sure you want to remove ?

Close

#

#### Now Playing

#### Queue

#### Playlists

#### Browse

#### Streams

#### Search

#### Alarm Clock

#### Settings

#### System

###

-

Position

#### Playlists

#### Browse

#### Play Queue

###

#####

###

#### Search

Search for artists, albums, or specific tracks.

#### Artists

#### Albums

#### Tracks

#### Streams

Play a specific stream/track and optionally save it to your favourites.